##  8. How should I configure Request links in the Portal?
Request links must be defined on the Resources tab of the Fact Sheet, by selecting Ordering Form, Additional Help, FAQ etc. If a new resource type is required, please contact our Customer Success team.
